extends Node2D

@onready var explosion_generator = $ExplosionGenerator
@onready var battle_ui = $CanvasLayer/BattleUI
@onready var player = $HiroPlayer
@onready var ai = $HiroAI
@onready var cutscene_manager = $CutsceneManager

func _ready():
	battle_ui.initialize(player.health, ai.health)
	battle_ui.set_player_health(player.health)
	battle_ui.set_enemy_health(ai.health)
	cutscene_manager.step()

func _on_player_defeated():
	if Globals.nsfw == true:
		explosion_generator.spawn(player.position)
	var cutscene = load("res://Cutscenes/prototype_defeated.tres")
	cutscene_manager.load_cutscene(cutscene)
	cutscene_manager.step()

func _on_ai_defeated():
	if Globals.nsfw == true:
		explosion_generator.spawn(ai.position)
		
func _on_cutscene_started(cutscene_name):
	$HiroPlayer.can_move = false
	$GameState.can_pause = false
	if cutscene_name == "prototype_start":
		$HiroAI.set_ai_enabled(false)
		$ReedAI.set_ai_enabled(false)

func _on_cutscene_finished(cutscene_name: String):
	print("Cutscene " + cutscene_name + " finished")
	$HiroPlayer.can_move = true
	$GameState.can_pause = true
	if cutscene_name == "prototype_start":
		$HiroAI.set_ai_enabled(true)
		$ReedAI.set_ai_enabled(true)


func _on_cutscene_manager_issued_command(command: CutsceneCommand, manager: CutsceneManager):
	if command is TurnCharacterCommand or command is LookAtTargetCommand:
		var character: CharacterBase = manager.get_node(command.character)
		var face_direction: Vector2 = command.get_direction(manager)
		assert(character is CharacterBase)
		character.set_animation_direction(face_direction)
		manager.step()
